@@ -1641,9 +1641,6 @@ gnome_program_postinit (GnomeProgram *program)
     /* Note! we cannot kill the program_modules array as that
      * may be needed later */
 
-    g_array_free (program->_priv->top_options_table, TRUE);
-    program->_priv->top_options_table = NULL;
-
     g_blow_chunks(); /* Try to compact memory usage a bit */
 
     program->_priv->state = APP_POSTINIT_DONE;
@@ -1730,12 +1727,14 @@ gnome_program_initv (GType type,
 	const char *ctmp;
 	const GnomeModuleInfo *libgnome_module;
 
-	program_module_list = g_ptr_array_new ();
-	program_modules = g_ptr_array_new ();
-
-	/* keep array NULL terminated */
-	g_ptr_array_add (program_modules, NULL);
-
+	if (!program_module_list)
+	    program_module_list = g_ptr_array_new ();
+	
+	if (!program_modules) {
+	    program_modules = g_ptr_array_new ();
+	      /* keep array NULL terminated */
+	    g_ptr_array_add (program_modules, NULL);
+	}
 	/* Register the requested modules. */
 	gnome_program_module_register (module_info);
 
